@@ -1,32 +1,19 @@
 #!/usr/bin/python3
 # -*- python -*-
 # -*- coding: utf-8 -*-
+# SPDX-License-Identifier: GPL-2.0-only
 #
 # Copyright (C) 2007-2015 Red Hat, Inc.
 #
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; version 2 of the License.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
-#
 
 import os
 import platform
 import re
 import time
 from functools import reduce
-from six.moves import range
 from procfs.utilist import bitmasklist
 
-VERSION = "0.5"
+VERSION = "0.7.3"
 
 
 def is_s390():
@@ -164,7 +151,7 @@ class pidstat:
 
     def load(self, basedir="/proc"):
         try:
-            f = open("%s/%d/stat" % (basedir, self.pid))
+            f = open(f"{basedir}/{self.pid}/stat")
         except FileNotFoundError:
             # The pid has disappeared, propagate the error
             raise
@@ -322,7 +309,7 @@ class pidstatus:
 
     def load(self, basedir="/proc"):
         self.fields = {}
-        with open("%s/%d/status" % (basedir, self.pid)) as f:
+        with open(f"{basedir}/{self.pid}/status") as f:
             for line in f.readlines():
                 fields = line.split(":")
                 if len(fields) != 2:
@@ -379,7 +366,7 @@ class process:
 
     def load_cmdline(self):
         try:
-            with open("/proc/%d/cmdline" % self.pid) as f:
+            with open(f"/proc/{self.pid}/cmdline") as f:
                 self.cmdline = f.readline().strip().split('\0')[:-1]
         except FileNotFoundError:
             """ This can happen when a pid disappears """
@@ -389,13 +376,13 @@ class process:
             self.cmdline = None
 
     def load_threads(self):
-        self.threads = pidstats("/proc/%d/task/" % self.pid)
+        self.threads = pidstats(f"/proc/{self.pid}/task/")
         # remove thread leader
         del self.threads[self.pid]
 
     def load_cgroups(self):
         self.cgroups = ""
-        with open("/proc/%d/cgroup" % self.pid) as f:
+        with open(f"/proc/{self.pid}/cgroup") as f:
             for line in reversed(f.readlines()):
                 if len(self.cgroups) != 0:
                     self.cgroups = self.cgroups + "," + line[:-1]
@@ -429,7 +416,7 @@ class process:
         >>>
         """
         self.environ = {}
-        with open("/proc/%d/environ" % self.pid) as f:
+        with open(f"/proc/{self.pid}/environ") as f:
             for x in f.readline().split('\0'):
                 if len(x) > 0:
                     y = x.split('=')
@@ -558,13 +545,13 @@ class pidstats:
         priorities = ""
         processed_pids = []
         while True:
-            name = "%s/%d" % (basename, cpu)
+            name = f"{basename}/{cpu}"
             pids = self.find_by_name(name)
             if not pids or len([n for n in pids if n not in processed_pids]) == 0:
                 break
             for pid in pids:
                 try:
-                    priorities += "%s," % self.processes[pid]["stat"]["rt_priority"]
+                    priorities += f'{self.processes[pid]["stat"]["rt_priority"]}'
                 except IOError:
                     # We're doing lazy loading of /proc files
                     # So if we get this exception is because the
@@ -586,7 +573,7 @@ class pidstats:
                 break
             for pid in pids:
                 try:
-                    priorities += "%s," % self.processes[pid]["stat"]["rt_priority"]
+                    priorities += f'{self.processes[pid]["stat"]["rt_priority"]}'
                 except IOError:
                     # We're doing lazy loading of /proc files
                     # So if we get this exception is because the
@@ -690,7 +677,7 @@ class interrupts:
 
     def parse_affinity(self, irq):
         try:
-            with open("/proc/irq/%s/smp_affinity" % irq) as f:
+            with open(f"/proc/irq/{irq}/smp_affinity") as f:
                 line = f.readline()
             return bitmasklist(line, self.nr_cpus)
         except IOError:
@@ -973,7 +960,7 @@ class smaps:
 
     def reload(self):
         line = None
-        with("/proc/%d/smaps" % self.pid) as f:
+        with open(f"/proc/{self.pid}/smaps") as f:
             while True:
                 line = self.parse_entry(f, line)
                 if not line:
@@ -1012,13 +999,11 @@ class cpustat:
                 self.guest = int(fields[8])
 
     def __repr__(self):
-        s = "< user: %s, nice: %s, system: %s, idle: %s, iowait: %s, irq: %s, softirq: %s" % \
-            (self.user, self.nice, self.system, self.idle,
-             self.iowait, self.irq, self.softirq)
+        s = f"< user: {self.user}, nice: {self.nice}, system: {self.system}, idle: {self.idle}, iowait: {self.iowait}, irq: {self.irq}, softirq: {self.softirq}"
         if hasattr(self, 'steal'):
-            s += ", steal: %d" % self.steal
+            s += f", steal: {self.steal}"
         if hasattr(self, 'guest'):
-            s += ", guest: %d" % self.guest
+            s += f", guest: {self.guest}"
         return s + ">"
 
 
@@ -1094,21 +1079,21 @@ if __name__ == '__main__':
     ints = interrupts()
 
     for i in list(ints.interrupts.keys()):
-        print("%s: %s" % (i, ints.interrupts[i]))
+        print(f"{i}: {ints.interrupts[i]}")
 
     options = cmdline()
     for o in list(options.options.keys()):
-        print("%s: %s" % (o, options.options[o]))
+        print(f"{o}: {options.options[o]}")
 
     cpu = cpuinfo()
-    print("\ncpuinfo data: %d processors" % cpu.nr_cpus)
+    print(f"\ncpuinfo data: {cpu.nr_cpus} processors")
     for tag in list(cpu.keys()):
-        print("%s=%s" % (tag, cpu[tag]))
+        print(f"{tag}={cpu[tag]}")
 
     print("smaps:\n" + ("-" * 40))
     s = smaps(int(sys.argv[1]))
     for i in range(s.nr_entries):
-        print("%#x %s" % (s.entries[i].vm_start, s.entries[i].name))
+        print(f"{s.entries[i].vm_start:#x} {s.entries[i].name}")
     print("-" * 40)
     for a in s.find_by_name_fragment(sys.argv[2]):
         print(a["Size"])
@@ -1121,5 +1106,5 @@ if __name__ == '__main__':
         time.sleep(1)
         cs.reload()
         for cpu in cs:
-            print("%s: %d" % (cpu.name, cpu.usage))
+            print(f"{cpu}: {cs[cpu]}")
         print("-" * 10)
